@@ -8,6 +8,10 @@
 #include "xosview.h"
 #include <fstream.h>
 
+#ifdef USESYSCALLS
+#include <syscall.h>
+#include <linux/kernel.h>
+#endif
 
 static const char MEMFILENAME[] = "/proc/meminfo";
 
@@ -39,9 +43,33 @@ void MemMeter::checkevent( void ){
   drawfields();
 }
 
+#ifdef USESYSCALLS
+void MemMeter::getmeminfo( void ){
+  struct sysinfo sinfo;
+
+  syscall( SYS_sysinfo, &sinfo );
+
+  total_ = sinfo.totalram;
+  fields_[3] = sinfo.freeram;
+  fields_[1] = sinfo.sharedram;
+  fields_[2] = sinfo.bufferram;
+
+  fields_[0] = total_ - fields_[3] - fields_[2] - fields_[1];
+  if ( fields_[0] < 0 ){
+    // Fixing up the user field
+    fields_[0] = 0;
+
+    // Fixing up the buffers field
+    fields_[2] = total_ - fields_[3] - fields_[1];
+  }
+
+  FieldMeter::used( (int)((100 * (total_ - fields_[3])) / total_) );
+}
+#else
 void MemMeter::getmeminfo( void ){
   float used;
   char buf[256];  
+
   ifstream meminfo( MEMFILENAME );
 
   if ( !meminfo ){
@@ -50,12 +78,19 @@ void MemMeter::getmeminfo( void ){
   }
 
   meminfo.getline( buf, 256 );
+
   meminfo >>buf >>total_ >>used >>fields_[3] >>fields_[1] >>fields_[2];
 
-//  fields_[0] = used - fields_[1] - fields_[2];
   fields_[0] = total_ - fields_[3] - fields_[2] - fields_[1];
-  if ( fields_[0] < 0 )
+  if ( fields_[0] < 0 ){
+    // Fixing up the user field
     fields_[0] = 0;
 
+    // Fixing up the buffers field
+    fields_[2] = total_ - fields_[3] - fields_[1];
+  }
+
   FieldMeter::used( (int)((100 * (total_ - fields_[3])) / total_) );
 }
+#endif
+
