@@ -8,6 +8,11 @@
 #include "xosview.h"
 #include <fstream.h>
 
+#ifdef USESYSCALLS
+#include <syscall.h>
+#include <linux/kernel.h>
+#endif
+
 
 static const char MEMFILENAME[] = "/proc/meminfo";
 
@@ -35,6 +40,26 @@ void SwapMeter::checkevent( void ){
   drawfields();
 }
 
+
+#ifdef USESYSCALLS
+void SwapMeter::getswapinfo( void ){
+  struct sysinfo sinfo;
+
+  syscall( SYS_sysinfo, &sinfo );
+
+  total_ = sinfo.totalswap;
+  fields_[0] = total_ - sinfo.freeswap;
+  fields_[1] = sinfo.freeswap;
+
+  if ( total_ == 0 ){
+    total_ = 1;
+    fields_[0] = 0;
+    fields_[1] = 1;
+  }
+
+  used( (int)((100 * fields_[0]) / total_ ) );
+}
+#else
 void SwapMeter::getswapinfo( void ){
   char buf[256];  
   ifstream meminfo( MEMFILENAME );
@@ -56,3 +81,5 @@ void SwapMeter::getswapinfo( void ){
 
   used( (int)((100 * fields_[0]) / total_ ) );
 }
+#endif
+
