@@ -44,6 +44,8 @@ public:
     { XSetBackground( display_, gc_, pixelvalue ); }
   unsigned long foreground( void ) { return fgcolor_; }
   unsigned long background( void ) { return bgcolor_; }
+  void resize( int width, int height ) 
+    { XResizeWindow( display_, window_, width, height ); }
   void lineWidth( int width )
     {
       XGCValues xgcv;
